Chapter 6: Searching for Structure in Point Data
------------------------------------------------
This chapter covers high-dimensional point statistics, including density
estimation, clustering, and correlation functions.
